@@ -31,6 +31,7 @@ from .utils import (
     ensure_datetime,
     find_files,
     flattened,
+    is_url,
     load_jsonl,
     move_file,
     yaml_load,
@@ -254,8 +255,15 @@ def organize_external_files(
                     ext_file_dict["external_files_renamed"],
                 )
             ):
+                if is_url(str(name_old)):
+                    continue
                 new_path = op.join(dandiset_path, op.dirname(e["dandi_path"]), name_new)
                 name_old_str = str(name_old)
+                if not op.isabs(name_old_str):
+                    name_old_str = op.join(op.dirname(e["path"]), name_old_str)
+                if not op.exists(name_old_str):
+                    lgr.error("%s does not exist", name_old_str)
+                    raise FileNotFoundError(f"{name_old_str} does not exist")
                 os.makedirs(op.dirname(new_path), exist_ok=True)
                 if files_mode == "symlink":
                     os.symlink(name_old_str, new_path)
@@ -882,6 +890,18 @@ def organize(
             "--media-files-mode not specified, setting to recommended mode: 'symlink' "
         )
 
+    # look for multiple nwbfiles linking to one video:
+    if media_files_mode == "move":
+        videos_list = []
+        for meta in metadata:
+            for ext_ob in meta["external_file_objects"]:
+                videos_list.extend(ext_ob.get("external_files", []))
+        if len(set(videos_list)) < len(videos_list):
+            raise ValueError(
+                "multiple nwbfiles linked to one video file, "
+                "provide 'media_files_mode' as copy/symlink/hardlink"
+            )
+
     metadata = _create_external_file_names(metadata)
 
     # Verify first that the target paths do not exist yet, and fail if they do
